/*
 * Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */

package main

import (
	"flag"
	"gitlab.nrao.edu/ssa/gocapo/helpers"
	"os"
	"ssa/iiwf_trigger/pkg/ingest"
)

var DefaultImgPath = "Not Set"

func main() {
	var imgSetPath string
	var capo ingest.CapoInput

	flag.StringVar(&imgSetPath, "path", DefaultImgPath, "[Required] Path to a cached VLASS image set")
	flag.StringVar(&capo.CapoPath, "prop", helpers.DefaultCapoPath, "[Optional] Path to the CAPO properties file, defaults to CAPO_PATH env variable")
	flag.StringVar(&capo.CapoProfile, "profile", os.Getenv("CAPO_PROFILE"), "The CAPO profile to use, defaults to CAPO_PROFILE env variable")
	flag.Parse()

	// Make sure a path was provided
	if len(imgSetPath) == 0 {
		flag.Usage()
		return
	}

	locator := ingest.GetCalibrationLocator(imgSetPath, capo)
	ingest.CallIngestionEndpoint(imgSetPath, locator, capo)
}
