/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Pipe, PipeTransform } from '@angular/core';

@Pipe({
  name: 'coordFormat'
})
export class CoordFormatPipe implements PipeTransform {

  transform(value: any, args?: any): any {
    if (!value) return null;
    let inangle = parseFloat(value);
    let degreeSign = '°';

    if(args){
      switch (args) {
        case 'DMS':
          let angD = Math.floor(inangle);
          let angDM = Math.floor(Math.abs(inangle - angD) * 60);
          let angDMS = (((Math.abs(inangle - angD) * 60) - angDM) * 60).toFixed(3);

          return angD + degreeSign + angDM + "'" + angDMS + '"';
        case 'HMS':
          let angH = Math.floor(inangle / 15); // 15 degree per Earth hour
          let angM = Math.floor(Math.abs((inangle / 15) - angH) * 60);
          let angS = (((Math.abs((inangle / 15) - angH) * 60) - angM) * 60).toFixed(3);

          return angH + 'h' + angM + 'm' + angS + 's';
        case 'rad':
          return (inangle * Math.PI / 180) + ' rad';
        default:
          return inangle + degreeSign;
      }
    }
      return null;
  }

}
