# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""template updates for notification changes

Revision ID: ca1f4d78c1a0
Revises: c98733cfe926
Create Date: 2022-04-22 10:12:33.290711

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "ca1f4d78c1a0"
down_revision = "c98733cfe926"
branch_labels = None
depends_on = None


# Carta Expired needs no changes

# Carta Ready:
old_carta_ready = """To: {{destination_email}}
Subject: NRAO CARTA Session Ready


Dear User,

Your CARTA session is now available.

Please use the following link to access your CARTA session:
{{carta_url}}

You will be notified when your session has expired.

Best regards,
NRAO Workspaces

"""

new_carta_ready = """To: {{destination_email}}
Subject: NRAO CARTA Session Ready


Dear User,

Your CARTA session is now available.

Please use the following link to access your CARTA session:
{{version.workflow_metadata.carta_url}}

You will be notified when your session has expired.

Best regards,
NRAO Workspaces

"""

# Complete Email:

old_workflow_complete = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{request_id}}: Complete


    Dear User,

    Thank you for using NRAO Workspaces.

    Your {{capbility_name}} request is now complete.

    Best regards,
    NRAO Workspaces
"""

new_workflow_complete = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{version.capability_request_id}}: Complete


    Dear User,

    Thank you for using NRAO Workspaces.

    Your {{version.capbility_name}} request is now complete.

    Best regards,
    NRAO Workspaces"""

# Failed Email:

old_workflow_failed = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{request_id}}: Failed


    Dear User,

    Thank you for using NRAO Workspaces.

    Your {{capability_name}} request #{{request_id}} has failed.

    Best regards,
    NRAO Workspaces
"""

new_workflow_failed = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{version.capability_request_id}}: Failed


    Dear User,

    Thank you for using NRAO Workspaces.

    Your {{version.capability_name}} request #{{version.capability_request_id}} has failed.

    Best regards,
    NRAO Workspaces
"""

# Ingested Email:

old_ingested_email = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{request_id}} has been ingested


Dear User,

Thank you for using NRAO Workspaces.

Your {{capability_name}} request #{{request_id}} has successfully had its products ingested into the archive.

{{#qa}}
QA NOTES for request #{{request_id}}:
{{qa}}
{{/qa}}

Best regards,
NRAO Workspaces
"""


# Ingestion Failed Email:

old_ingestion_fail_email = """To: {{destination_email}}
Subject: NRAO Workspaces - Ingestion failed for request #{{request_id}}


Dear DA,

A {{capability_name}} request #{{request_id}} failed to be ingested into the archive.

Best regards,
NRAO Workspaces
"""

new_ingestion_fail_email = """To: {{destination_email}}
Subject: NRAO Workspaces - Ingestion failed for request #{{version.capability.request_id}}


Dear DA,

A {{version.capability_name}} request #{{version.capability_request_id}} failed to be ingested into the archive.

Best regards,
NRAO Workspaces
"""

# Ready for QA Email:

old_qa_ready_email = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{request_id}}: Ready for QA


Dear DA,

A {{capability_name}} request is ready for QA.

UI for passing QA is currently unavailable, and by default all requests are QA-passed. Sorry for the inconvenience.

Request status can be checked here:

{{status_link}}

Best regards,

NRAO Workspaces
"""

new_qa_ready_email = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{version.capability_request_id}}: Ready for QA


Dear DA,

A {{version.capability_name}} request is ready for QA.

You can review the weblog, add notes, and decide the QA status here:

{{version.request.status_url}}

Best regards,

NRAO Workspaces
"""

# Submitted Email:

old_workflow_submitted = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{request_id}}: Submitted


      Dear User,

      Your {{capability_name}} request has been submitted.

      You will be notified when it is complete.

      The status of your request can be tracked here:

      {{{status_link}}}

      Best regards,

      NRAO Workspaces
"""

new_workflow_submitted = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{version.capability_request_id}}: Submitted


      Dear User,

      Your {{version.capability_name}} request has been submitted.

      You will be notified when it is complete.

      The status of your request can be tracked here:

      {{{version.request.status_url}}}

      Best regards,

      NRAO Workspaces
"""


def upgrade():

    # No Carta Expired Changes

    # Carta Ready
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{new_carta_ready}' WHERE name='carta_ready'
        """
    )

    # WF Complete
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{new_workflow_complete}' WHERE name='workflow-complete'
        """
    )

    # WF Failed
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{new_workflow_failed}' WHERE name='workflow-failed'
        """
    )

    # WF Submitted
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{new_workflow_submitted}' WHERE name='workflow-submitted'
        """
    )

    # QA Ready
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{new_qa_ready_email}' WHERE name='ready-for-QA_email'
        """
    )

    # Ingest Failed
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{new_ingestion_fail_email}' WHERE name='ingestion_failed_email'
        """
    )

    # Remove old Ingested template:
    op.execute(
        """
        DELETE FROM notification_templates WHERE name='ingested_email'
        """
    )


def downgrade():

    # No Carta Expired Changes

    # Carta Ready
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{old_carta_ready}' WHERE name='carta_ready'
        """
    )

    # WF Complete
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{old_workflow_complete}' WHERE name='workflow-complete'
        """
    )

    # WF Failed
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{old_workflow_failed}' WHERE name='workflow-failed'
        """
    )

    # WF Submitted
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{old_workflow_submitted}' WHERE name='workflow-submitted'
        """
    )

    # QA Ready
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{old_qa_ready_email}' WHERE name='ready-for-QA_email'
        """
    )

    # Ingest Failed
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{old_ingestion_fail_email}' WHERE name='ingestion_failed_email'
        """
    )

    # Ingested
    op.execute(
        f"""
        INSERT INTO notification_templates (name, description, template)  VALUES
        'ingested_email',
        'An email template for notifying a user that their capability request has been ingested into the archive',
        E'{old_ingested_email}'
        """
    )
