#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
from abc import ABC


class ProductIF(ABC):
    """
    Parent class for all science products
    """

    pass


class CurrentArchiveProductIF(ProductIF):
    """
    Product that currently exists in the archive and can be located with a product locator
    """

    pass


class FutureArchiveProductIF(ProductIF):
    """
    Class that represents a product that will be ingested into the archive after a capability
    execution has completed
    """

    pass


class FutureProductTypeIF(ABC):
    """
    Class that represents all possible types of future products
    """

    pass


class FutureExecutionBlockIF(FutureProductTypeIF):
    """
    Class that represents an EB that will be the result of a completed capability
    execution
    """

    pass


class FutureProductIF(FutureProductTypeIF):
    """
    Class that represents a product that will be the result of a completed capability execution
    """

    pass


class ProductTypeIF(ABC):
    """
    Class that represents all possible types of products that can result from a capability execution
    """

    # FIXME: We haven't decided how we want to implement this yet
    pass


class ProductLocatorIF(ABC):
    """
    Class that represents an archive product locator
    """

    pass
